@@ -1,7 +1,11 @@
 package org.gcube.application.geoportalcommon.shared.geoportal.ucd;
 
 public enum GEOPORTAL_CONFIGURATION_TYPE {
-	item_fields("itemFields"), gcube_profiles("gcubeProfiles"), actions_definition("actionsDefinition");
+	item_fields("itemFields"), 
+	gcube_profiles("gcubeProfiles"), 
+	actions_definition("actionsDefinition"), 
+	grouped_overlay_layers("grouped_overlay_layers"),
+	grouped_cross_filtering_layers("grouped_cross_filtering_layers");
 
 	String id;
 
